@@ -69,8 +69,6 @@ clutter_geometry_free (ClutterGeometry *geometry)
  * Find the union of two rectangles represented as #ClutterGeometry.
  *
  * Since: 1.4
- *
- * Deprecated: 1.16: Use #ClutterRect and clutter_rect_union()
  */
 void
 clutter_geometry_union (const ClutterGeometry *geometry_a,
@@ -103,8 +101,6 @@ clutter_geometry_union (const ClutterGeometry *geometry_a,
  * %FALSE.
  *
  * Since: 1.4
- *
- * Deprecated: 1.16: Use #ClutterRect and clutter_rect_intersection()
  */
 gboolean
 clutter_geometry_intersects (const ClutterGeometry *geometry0,
@@ -184,7 +180,7 @@ clutter_vertex_new (gfloat x,
 }
 
 /**
- * clutter_vertex_alloc: (constructor)
+ * clutter_vertex_alloc:
  *
  * Allocates a new, empty #ClutterVertex.
  *
@@ -288,17 +284,6 @@ clutter_vertex_equal (const ClutterVertex *vertex_a,
          fabsf (vertex_a->z - vertex_b->z) < FLOAT_EPSILON;
 }
 
-static void
-clutter_vertex_interpolate (const ClutterVertex *a,
-                            const ClutterVertex *b,
-                            double               progress,
-                            ClutterVertex       *res)
-{
-  res->x = a->x + (b->x - a->x) * progress;
-  res->y = a->y + (b->y - a->y) * progress;
-  res->z = a->z + (b->z - a->z) * progress;
-}
-
 static gboolean
 clutter_vertex_progress (const GValue *a,
                          const GValue *b,
@@ -309,7 +294,9 @@ clutter_vertex_progress (const GValue *a,
   const ClutterVertex *bv = g_value_get_boxed (b);
   ClutterVertex res;
 
-  clutter_vertex_interpolate (av, bv, progress, &res);
+  res.x = av->x + (bv->x - av->x) * progress;
+  res.y = av->y + (bv->y - av->y) * progress;
+  res.z = av->z + (bv->z - av->z) * progress;
 
   g_value_set_boxed (retval, &res);
 
@@ -390,28 +377,8 @@ G_DEFINE_BOXED_TYPE (ClutterMargin, clutter_margin,
  * ClutterPoint
  */
 
-static const ClutterPoint _clutter_point_zero = CLUTTER_POINT_INIT_ZERO;
-
 /**
- * clutter_point_zero:
- *
- * A point centered at (0, 0).
- *
- * The returned value can be used as a guard.
- *
- * Return value: a point centered in (0, 0); the returned #ClutterPoint
- *   is owned by Clutter and it should not be modified or freed.
- *
- * Since: 1.12
- */
-const ClutterPoint *
-clutter_point_zero (void)
-{
-  return &_clutter_point_zero;
-}
-
-/**
- * clutter_point_alloc: (constructor)
+ * clutter_point_alloc:
  *
  * Allocates a new #ClutterPoint.
  *
@@ -479,7 +446,7 @@ clutter_point_copy (const ClutterPoint *point)
 void
 clutter_point_free (ClutterPoint *point)
 {
-  if (point != NULL && point != &_clutter_point_zero)
+  if (point != NULL)
     g_slice_free (ClutterPoint, point);
 }
 
@@ -579,7 +546,7 @@ G_DEFINE_BOXED_TYPE_WITH_CODE (ClutterPoint, clutter_point,
  */
 
 /**
- * clutter_size_alloc: (constructor)
+ * clutter_size_alloc:
  *
  * Allocates a new #ClutterSize.
  *
@@ -705,8 +672,6 @@ G_DEFINE_BOXED_TYPE_WITH_CODE (ClutterSize, clutter_size,
  * ClutterRect
  */
 
-static const ClutterRect _clutter_rect_zero = CLUTTER_RECT_INIT_ZERO;
-
 static gboolean clutter_rect_progress (const GValue *a,
                                        const GValue *b,
                                        gdouble       progress,
@@ -741,27 +706,7 @@ clutter_rect_normalize_internal (ClutterRect *rect)
 }
 
 /**
- * clutter_rect_zero:
- *
- * A #ClutterRect with #ClutterRect.origin set at (0, 0) and a size
- * of 0.
- *
- * The returned value can be used as a guard.
- *
- * Return value: a rectangle with origin in (0, 0) and a size of 0.
- *   The returned #ClutterRect is owned by Clutter and it should not
- *   be modified or freed.
- *
- * Since: 1.12
- */
-const ClutterRect *
-clutter_rect_zero (void)
-{
-  return &_clutter_rect_zero;
-}
-
-/**
- * clutter_rect_alloc: (constructor)
+ * clutter_rect_alloc:
  *
  * Creates a new, empty #ClutterRect.
  *
@@ -853,7 +798,7 @@ clutter_rect_copy (const ClutterRect *rect)
 void
 clutter_rect_free (ClutterRect *rect)
 {
-  if (rect != NULL && rect != &_clutter_rect_zero)
+  if (rect != NULL)
     g_slice_free (ClutterRect, rect);
 }
 
@@ -1057,7 +1002,7 @@ clutter_rect_intersection (ClutterRect *a,
   clutter_rect_normalize_internal (a);
   clutter_rect_normalize_internal (b);
 
-  x_1 = MAX (a->origin.x, b->origin.x);
+  x_1 = MAX (a->origin.x, b->origin.y);
   y_1 = MAX (a->origin.y, b->origin.y);
   x_2 = MIN (a->origin.x + a->size.width, b->origin.x + b->size.width);
   y_2 = MIN (a->origin.y + a->size.height, b->origin.y + b->size.height);
@@ -1263,7 +1208,7 @@ clutter_rect_progress (const GValue *a,
   const ClutterRect *rect_b = g_value_get_boxed (b);
   ClutterRect res = CLUTTER_RECT_INIT_ZERO;
 
-#define INTERPOLATE(r_a,r_b,member,field,factor)     ((r_a)->member.field + (((r_b)->member.field - ((r_a)->member.field)) * (factor)))
+#define INTERPOLATE(r_a,r_b,member,field,factor)     ((r_a)->member.field + (((r_b)->member.field - ((r_b)->member.field)) * (factor)))
 
   res.origin.x = INTERPOLATE (rect_a, rect_b, origin, x, progress);
   res.origin.y = INTERPOLATE (rect_a, rect_b, origin, y, progress);
@@ -1273,196 +1218,9 @@ clutter_rect_progress (const GValue *a,
 
 #undef INTERPOLATE
 
-  g_value_set_boxed (retval, &res);
-
-  return TRUE;
-}
-
-/**
- * ClutterMatrix:
- *
- * A type representing a 4x4 matrix.
- *
- * It is identicaly to #CoglMatrix.
- *
- * Since: 1.12
- */
-
-static gpointer
-clutter_matrix_copy (gpointer data)
-{
-  return cogl_matrix_copy (data);
-}
-
-static gboolean
-clutter_matrix_progress (const GValue *a,
-                         const GValue *b,
-                         gdouble       progress,
-                         GValue       *retval)
-{
-  const ClutterMatrix *matrix1 = g_value_get_boxed (a);
-  const ClutterMatrix *matrix2 = g_value_get_boxed (b);
-  ClutterVertex scale1 = CLUTTER_VERTEX_INIT (1.f, 1.f, 1.f);
-  float shear1[3] = { 0.f, 0.f, 0.f };
-  ClutterVertex rotate1 = CLUTTER_VERTEX_INIT_ZERO;
-  ClutterVertex translate1 = CLUTTER_VERTEX_INIT_ZERO;
-  ClutterVertex4 perspective1 = { 0.f, 0.f, 0.f, 0.f };
-  ClutterVertex scale2 = CLUTTER_VERTEX_INIT (1.f, 1.f, 1.f);
-  float shear2[3] = { 0.f, 0.f, 0.f };
-  ClutterVertex rotate2 = CLUTTER_VERTEX_INIT_ZERO;
-  ClutterVertex translate2 = CLUTTER_VERTEX_INIT_ZERO;
-  ClutterVertex4 perspective2 = { 0.f, 0.f, 0.f, 0.f };
-  ClutterVertex scale_res = CLUTTER_VERTEX_INIT (1.f, 1.f, 1.f);
-  float shear_res = 0.f;
-  ClutterVertex rotate_res = CLUTTER_VERTEX_INIT_ZERO;
-  ClutterVertex translate_res = CLUTTER_VERTEX_INIT_ZERO;
-  ClutterVertex4 perspective_res = { 0.f, 0.f, 0.f, 0.f };
-  ClutterMatrix res;
-
-  clutter_matrix_init_identity (&res);
-
-  _clutter_util_matrix_decompose (matrix1,
-                                  &scale1, shear1, &rotate1, &translate1,
-                                  &perspective1);
-  _clutter_util_matrix_decompose (matrix2,
-                                  &scale2, shear2, &rotate2, &translate2,
-                                  &perspective2);
-
-  /* perspective */
-  _clutter_util_vertex4_interpolate (&perspective1, &perspective2, progress, &perspective_res);
-  res.wx = perspective_res.x;
-  res.wy = perspective_res.y;
-  res.wz = perspective_res.z;
-  res.ww = perspective_res.w;
-
-  /* translation */
-  clutter_vertex_interpolate (&translate1, &translate2, progress, &translate_res);
-  cogl_matrix_translate (&res, translate_res.x, translate_res.y, translate_res.z);
-
-  /* rotation */
-  clutter_vertex_interpolate (&rotate1, &rotate2, progress, &rotate_res);
-  cogl_matrix_rotate (&res, rotate_res.x, 1.0f, 0.0f, 0.0f);
-  cogl_matrix_rotate (&res, rotate_res.y, 0.0f, 1.0f, 0.0f);
-  cogl_matrix_rotate (&res, rotate_res.z, 0.0f, 0.0f, 1.0f);
-
-  /* skew */
-  shear_res = shear1[2] + (shear2[2] - shear1[2]) * progress; /* YZ */
-  if (shear_res != 0.f)
-    _clutter_util_matrix_skew_yz (&res, shear_res);
-
-  shear_res = shear1[1] + (shear2[1] - shear1[1]) * progress; /* XZ */
-  if (shear_res != 0.f)
-    _clutter_util_matrix_skew_xz (&res, shear_res);
-
-  shear_res = shear1[0] + (shear2[0] - shear1[0]) * progress; /* XY */
-  if (shear_res != 0.f)
-    _clutter_util_matrix_skew_xy (&res, shear_res);
-
-  /* scale */
-  clutter_vertex_interpolate (&scale1, &scale2, progress, &scale_res);
-  cogl_matrix_scale (&res, scale_res.x, scale_res.y, scale_res.z);
+  clutter_rect_normalize_internal (&res);
 
   g_value_set_boxed (retval, &res);
 
   return TRUE;
 }
-
-G_DEFINE_BOXED_TYPE_WITH_CODE (ClutterMatrix, clutter_matrix,
-                               clutter_matrix_copy,
-                               clutter_matrix_free,
-                               CLUTTER_REGISTER_INTERVAL_PROGRESS (clutter_matrix_progress))
-
-/**
- * clutter_matrix_alloc:
- *
- * Allocates enough memory to hold a #ClutterMatrix.
- *
- * Return value: (transfer full): the newly allocated #ClutterMatrix
- *
- * Since: 1.12
- */
-ClutterMatrix *
-clutter_matrix_alloc (void)
-{
-  return g_new0 (ClutterMatrix, 1);
-}
-
-/**
- * clutter_matrix_free:
- * @matrix: (allow-none): a #ClutterMatrix
- *
- * Frees the memory allocated by clutter_matrix_alloc().
- *
- * Since: 1.12
- */
-void
-clutter_matrix_free (ClutterMatrix *matrix)
-{
-  cogl_matrix_free (matrix);
-}
-
-/**
- * clutter_matrix_init_identity:
- * @matrix: a #ClutterMatrix
- *
- * Initializes @matrix with the identity matrix, i.e.:
- *
- * |[
- *   .xx = 1.0, .xy = 0.0, .xz = 0.0, .xw = 0.0
- *   .yx = 0.0, .yy = 1.0, .yz = 0.0, .yw = 0.0
- *   .zx = 0.0, .zy = 0.0, .zz = 1.0, .zw = 0.0
- *   .wx = 0.0, .wy = 0.0, .wz = 0.0, .ww = 1.0
- * ]|
- *
- * Return value: (transfer none): the initialized #ClutterMatrix
- *
- * Since: 1.12
- */
-ClutterMatrix *
-clutter_matrix_init_identity (ClutterMatrix *matrix)
-{
-  cogl_matrix_init_identity (matrix);
-
-  return matrix;
-}
-
-/**
- * clutter_matrix_init_from_array:
- * @matrix: a #ClutterMatrix
- * @values: (array fixed-size=16): a C array of 16 floating point values,
- *   representing a 4x4 matrix, with column-major order
- *
- * Initializes @matrix with the contents of a C array of floating point
- * values.
- *
- * Return value: (transfer none): the initialzed #ClutterMatrix
- *
- * Since: 1.12
- */
-ClutterMatrix *
-clutter_matrix_init_from_array (ClutterMatrix *matrix,
-                                const float    values[16])
-{
-  cogl_matrix_init_from_array (matrix, values);
-
-  return matrix;
-}
-
-/**
- * clutter_matrix_init_from_matrix:
- * @a: the #ClutterMatrix to initialize
- * @b: the #ClutterMatrix to copy
- *
- * Initializes the #ClutterMatrix @a with the contents of the
- * #ClutterMatrix @b.
- *
- * Return value: (transfer none): the initialized #ClutterMatrix
- *
- * Since: 1.12
- */
-ClutterMatrix *
-clutter_matrix_init_from_matrix (ClutterMatrix       *a,
-                                 const ClutterMatrix *b)
-{
-  return memcpy (a, b, sizeof (ClutterMatrix));
-}
