@@ -164,8 +164,12 @@ typedef enum { /*< prefix=CLUTTER_REQUEST >*/
  *   registered global alpha functions
  *
  * The animation modes used by #ClutterAlpha and #ClutterAnimation. This
- * enumeration can be expanded in later versions of Clutter. See the
- * #ClutterAlpha documentation for a graph of all the animation modes.
+ * enumeration can be expanded in later versions of Clutter.
+ *
+ * <figure id="easing-modes">
+ *   <title>Easing modes provided by Clutter</title>
+ *   <graphic fileref="easing-modes.png" format="PNG"/>
+ * </figure>
  *
  * Every global alpha function registered using clutter_alpha_register_func()
  * or clutter_alpha_register_closure() will have a logical id greater than
@@ -1233,6 +1237,24 @@ typedef enum { /*< prefix=CLUTTER_SCROLL >*/
   CLUTTER_SCROLL_BOTH         = CLUTTER_SCROLL_HORIZONTALLY | CLUTTER_SCROLL_VERTICALLY
 } ClutterScrollMode;
 
+/**
+ * ClutterGridPosition:
+ * @CLUTTER_GRID_POSITION_LEFT: left position
+ * @CLUTTER_GRID_POSITION_RIGHT: right position
+ * @CLUTTER_GRID_POSITION_TOP: top position
+ * @CLUTTER_GRID_POSITION_BOTTOM: bottom position
+ *
+ * Grid position modes.
+ *
+ * Since: 1.12
+ */
+typedef enum {
+  CLUTTER_GRID_POSITION_LEFT,
+  CLUTTER_GRID_POSITION_RIGHT,
+  CLUTTER_GRID_POSITION_TOP,
+  CLUTTER_GRID_POSITION_BOTTOM
+} ClutterGridPosition;
+
 G_END_DECLS
 
 #endif /* __CLUTTER_ENUMS_H__ */
