@@ -66,7 +66,7 @@ G_BEGIN_DECLS
 /**
  * CLUTTER_EVENT_STOP:
  *
- * Stops the propagattion of an event; this macro should be used
+ * Stops the propagation of an event; this macro should be used
  * in event-related signals.
  *
  * Since: 1.10
@@ -115,6 +115,14 @@ typedef struct _ClutterStageStateEvent  ClutterStageStateEvent;
 typedef struct _ClutterCrossingEvent    ClutterCrossingEvent;
 typedef struct _ClutterTouchEvent       ClutterTouchEvent;
 
+/**
+ * ClutterEventSequence:
+ *
+ * The <structname>ClutterEventSequence</structname> structure is an opaque
+ * type used to denote the event sequence of a touch event.
+ *
+ * Since: 1.12
+ */
 typedef struct _ClutterEventSequence    ClutterEventSequence;
 
 /**
@@ -458,6 +466,11 @@ double                  clutter_event_get_angle                 (const ClutterEv
 gdouble *               clutter_event_get_axes                  (const ClutterEvent     *event,
                                                                  guint                  *n_axes);
 
+CLUTTER_AVAILABLE_IN_1_12
+gboolean                clutter_event_has_shift_modifier        (const ClutterEvent     *event);
+CLUTTER_AVAILABLE_IN_1_12
+gboolean                clutter_event_has_control_modifier      (const ClutterEvent     *event);
+
 void                    clutter_event_set_key_symbol            (ClutterEvent           *event,
                                                                  guint                   key_sym);
 guint                   clutter_event_get_key_symbol            (const ClutterEvent     *event);
