@@ -44,7 +44,7 @@
 
 /**
  * SECTION:clutter-grid-layout
- * @Short_description: A layout manager for a grid of actors
+ * @Short_description: Pack widgets in a rows and columns
  * @Title: ClutterGridLayout
  * @See_also: #ClutterTableLayout, #ClutterBoxLayout
  *
@@ -66,6 +66,7 @@
 #define CLUTTER_TYPE_GRID_CHILD          (clutter_grid_child_get_type ())
 #define CLUTTER_GRID_CHILD(obj)          (G_TYPE_CHECK_INSTANCE_CAST ((obj), CLUTTER_TYPE_GRID_CHILD, ClutterGridChild))
 #define CLUTTER_IS_GRID_CHILD(obj)       (G_TYPE_CHECK_INSTANCE_TYPE ((obj), CLUTTER_TYPE_GRID_CHILD))
+#define CLUTTER_GRID_LAYOUT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_GRID_LAYOUT, ClutterGridLayoutPrivate))
 
 typedef struct _ClutterGridChild        ClutterGridChild;
 typedef struct _ClutterLayoutMetaClass  ClutterGridChildClass;
@@ -172,11 +173,9 @@ static GParamSpec *child_props[PROP_CHILD_LAST];
 GType clutter_grid_child_get_type (void);
 
 G_DEFINE_TYPE (ClutterGridChild, clutter_grid_child,
-               CLUTTER_TYPE_LAYOUT_META)
-
-G_DEFINE_TYPE_WITH_PRIVATE (ClutterGridLayout,
-                            clutter_grid_layout,
-                            CLUTTER_TYPE_LAYOUT_MANAGER)
+               CLUTTER_TYPE_LAYOUT_META);
+G_DEFINE_TYPE (ClutterGridLayout, clutter_grid_layout,
+               CLUTTER_TYPE_LAYOUT_MANAGER);
 
 
 #define GET_GRID_CHILD(grid, child) \
@@ -361,7 +360,7 @@ clutter_grid_request_update_child_attach (ClutterGridRequest *request,
 
           td = clutter_actor_get_text_direction (container);
           rtl = (td == CLUTTER_TEXT_DIRECTION_RTL) ? TRUE : FALSE;
-          side = rtl ? CLUTTER_GRID_POSITION_LEFT : CLUTTER_GRID_POSITION_RIGHT;
+          side = rtl ? CLUTTER_GRID_POSITION_RIGHT : CLUTTER_GRID_POSITION_LEFT;
         }
       else
         {
@@ -371,8 +370,6 @@ clutter_grid_request_update_child_attach (ClutterGridRequest *request,
         }
 
       sibling = clutter_actor_get_previous_sibling (actor);
-      if (sibling)
-        clutter_grid_layout_insert_next_to (request->grid, sibling, side);
       grid_attach_next_to (request->grid, actor, sibling, side,
                            CHILD_WIDTH (grid_child),
                            CHILD_HEIGHT (grid_child));
@@ -1389,6 +1386,9 @@ clutter_grid_layout_allocate (ClutterLayoutManager   *layout,
   ClutterGridLines *lines;
   ClutterActorIter iter;
   ClutterActor *child;
+  gboolean use_animations;
+  ClutterAnimationMode mode;
+  guint duration, delay;
 
   request.grid = self;
 
@@ -1409,6 +1409,11 @@ clutter_grid_layout_allocate (ClutterLayoutManager   *layout,
   clutter_grid_request_position (&request, 0);
   clutter_grid_request_position (&request, 1);
 
+  use_animations = clutter_layout_manager_get_easing_state (layout,
+                                                            &mode,
+                                                            &duration,
+                                                            &delay);
+
   clutter_actor_iter_init (&iter, CLUTTER_ACTOR (container));
   while (clutter_actor_iter_next (&iter, &child))
     {
@@ -1426,17 +1431,25 @@ clutter_grid_layout_allocate (ClutterLayoutManager   *layout,
                       &y, &height);
       x += allocation->x1;
       y += allocation->y1;
+      clutter_actor_box_set_origin (&child_allocation, x, y);
+      clutter_actor_box_set_size (&child_allocation, width, height);
 
       CLUTTER_NOTE (LAYOUT, "Allocation for %s { %.2f, %.2f - %.2f x %.2f }",
                     _clutter_actor_get_debug_name (child),
                     x, y, width, height);
 
-      child_allocation.x1 = x;
-      child_allocation.y1 = y;
-      child_allocation.x2 = child_allocation.x1 + width;
-      child_allocation.y2 = child_allocation.y1 + height;
+      if (use_animations)
+        {
+          clutter_actor_save_easing_state (child);
+          clutter_actor_set_easing_mode (child, mode);
+          clutter_actor_set_easing_duration (child, duration);
+          clutter_actor_set_easing_delay (child, delay);
+        }
 
       clutter_actor_allocate (child, &child_allocation, flags);
+
+      if (use_animations)
+        clutter_actor_restore_easing_state (child);
     }
 }
 
@@ -1528,6 +1541,8 @@ clutter_grid_layout_class_init (ClutterGridLayoutClass *klass)
 
   layout_class = CLUTTER_LAYOUT_MANAGER_CLASS (klass);
 
+  g_type_class_add_private (klass, sizeof (ClutterGridLayoutPrivate));
+
   object_class->set_property = clutter_grid_layout_set_property;
   object_class->get_property = clutter_grid_layout_get_property;
 
@@ -1615,15 +1630,17 @@ clutter_grid_layout_class_init (ClutterGridLayoutClass *klass)
 static void
 clutter_grid_layout_init (ClutterGridLayout *self)
 {
-  self->priv = clutter_grid_layout_get_instance_private (self);
+  ClutterGridLayoutPrivate *priv;
 
-  self->priv->orientation = CLUTTER_ORIENTATION_HORIZONTAL;
+  self->priv = priv = CLUTTER_GRID_LAYOUT_GET_PRIVATE (self);
 
-  self->priv->linedata[0].spacing = 0;
-  self->priv->linedata[1].spacing = 0;
+  priv->orientation = CLUTTER_ORIENTATION_HORIZONTAL;
 
-  self->priv->linedata[0].homogeneous = FALSE;
-  self->priv->linedata[1].homogeneous = FALSE;
+  priv->linedata[0].spacing = 0;
+  priv->linedata[1].spacing = 0;
+
+  priv->linedata[0].homogeneous = FALSE;
+  priv->linedata[1].homogeneous = FALSE;
 }
 
 /**
