@@ -128,24 +128,12 @@ struct _ClutterTableLayoutPrivate
 
   GArray *columns;
   GArray *rows;
-
-  gulong easing_mode;
-  guint easing_duration;
-
-  guint is_animating   : 1;
-  guint use_animations : 1;
 };
 
 struct _ClutterTableChild
 {
   ClutterLayoutMeta parent_instance;
 
-  /* the last stable allocation before an animation; it is used as the
-   * initial ActorBox when interpolating. If has_last_allocation is
-   * FALSE then this value is not yet known
-   */
-  ClutterActorBox last_allocation;
-
   gint col;
   gint row;
 
@@ -159,7 +147,6 @@ struct _ClutterTableChild
   guint y_expand            : 1;
   guint x_fill              : 1;
   guint y_fill              : 1;
-  guint has_last_allocation : 1;
 };
 
 enum
@@ -184,8 +171,6 @@ enum
 
   PROP_ROW_SPACING,
   PROP_COLUMN_SPACING,
-  PROP_USE_ANIMATIONS,
-  PROP_EASING_MODE,
   PROP_EASING_DURATION
 };
 
@@ -651,8 +636,6 @@ clutter_table_child_init (ClutterTableChild *self)
 
   self->x_fill = TRUE;
   self->y_fill = TRUE;
-
-  self->has_last_allocation = FALSE;
 }
 
 static GType
@@ -717,6 +700,7 @@ calculate_col_widths (ClutterTableLayout *self,
   ClutterActor *actor, *child;
   gint i;
   DimensionData *columns;
+  ClutterOrientation orientation = CLUTTER_ORIENTATION_HORIZONTAL;
 
   update_row_col (self, container);
   g_array_set_size (priv->columns, 0);
@@ -767,7 +751,10 @@ calculate_col_widths (ClutterTableLayout *self,
       col->pref_size = MAX (col->pref_size, c_pref);
 
       if (!col->expand)
-        col->expand = meta->x_expand;
+        {
+          col->expand = clutter_actor_needs_expand (child, orientation) ||
+            meta->x_expand;
+        }
     }
 
   /* STAGE TWO: take spanning children into account */
@@ -816,7 +803,11 @@ calculate_col_widths (ClutterTableLayout *self,
             }
 
           if (!columns[i].expand)
-            columns[i].expand = meta->x_expand;
+            {
+              columns[i].expand = clutter_actor_needs_expand (child,
+                                                              orientation) ||
+                meta->x_expand;
+            }
         }
       min_width += priv->col_spacing * (meta->col_span - 1);
       pref_width += priv->col_spacing * (meta->col_span - 1);
@@ -984,6 +975,7 @@ calculate_row_heights (ClutterTableLayout *self,
   ClutterActor *actor, *child;
   gint i;
   DimensionData *rows, *columns;
+  ClutterOrientation orientation = CLUTTER_ORIENTATION_VERTICAL;
 
   update_row_col (self, container);
   g_array_set_size (priv->rows, 0);
@@ -1037,7 +1029,10 @@ calculate_row_heights (ClutterTableLayout *self,
       row->pref_size = MAX (row->pref_size, c_pref);
 
       if (!row->expand)
-        row->expand = meta->y_expand;
+        {
+          row->expand = clutter_actor_needs_expand (child, orientation) ||
+            meta->y_expand;
+        }
     }
 
   /* STAGE TWO: take spanning children into account */
@@ -1088,7 +1083,11 @@ calculate_row_heights (ClutterTableLayout *self,
             }
 
           if (!rows[i].expand)
-            rows[i].expand = meta->y_expand;
+            {
+              rows[i].expand = clutter_actor_needs_expand (child,
+                                                           orientation) ||
+                meta->y_expand;
+            }
         }
 
       min_height += priv->row_spacing * (meta->row_span - 1);
@@ -1377,6 +1376,10 @@ clutter_table_layout_allocate (ClutterLayoutManager   *layout,
   gint row_spacing, col_spacing;
   gint i;
   DimensionData *rows, *columns;
+  gboolean use_animations;
+  ClutterAnimationMode easing_mode;
+  guint easing_duration, easing_delay;
+
 
   update_row_col (self, container);
   if (priv->n_cols < 1 || priv->n_rows < 1)
@@ -1397,6 +1400,11 @@ clutter_table_layout_allocate (ClutterLayoutManager   *layout,
   rows = (DimensionData *) (void *) priv->rows->data;
   columns = (DimensionData *) (void *) priv->columns->data;
 
+  use_animations = clutter_layout_manager_get_easing_state (layout,
+                                                            &easing_mode,
+                                                            &easing_duration,
+                                                            &easing_delay);
+
   for (child = clutter_actor_get_first_child (actor);
        child != NULL;
        child = clutter_actor_get_next_sibling (child))
@@ -1492,19 +1500,24 @@ clutter_table_layout_allocate (ClutterLayoutManager   *layout,
       childbox.y1 = (float) child_y;
       childbox.y2 = (float) MAX (0, child_y + row_height);
 
-      if (priv->use_animations)
+      if (use_animations)
         {
           clutter_actor_save_easing_state (child);
-          clutter_actor_set_easing_mode (child, priv->easing_mode);
-          clutter_actor_set_easing_duration (child, priv->easing_duration);
+          clutter_actor_set_easing_mode (child, easing_mode);
+          clutter_actor_set_easing_duration (child, easing_duration);
+          clutter_actor_set_easing_delay (child, easing_delay);
         }
 
-      clutter_actor_allocate_align_fill (child, &childbox,
-                                         x_align, y_align,
-                                         x_fill, y_fill,
-                                         flags);
+      if (clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_HORIZONTAL) ||
+          clutter_actor_needs_expand (child, CLUTTER_ORIENTATION_VERTICAL))
+        clutter_actor_allocate (child, &childbox, flags);
+      else
+        clutter_actor_allocate_align_fill (child, &childbox,
+                                           x_align, y_align,
+                                           x_fill, y_fill,
+                                           flags);
 
-      if (priv->use_animations)
+      if (use_animations)
         clutter_actor_restore_easing_state (child);
     }
 }
@@ -1527,18 +1540,6 @@ clutter_table_layout_set_property (GObject      *gobject,
       clutter_table_layout_set_row_spacing (self, g_value_get_uint (value));
       break;
 
-    case PROP_USE_ANIMATIONS:
-      clutter_table_layout_set_use_animations (self, g_value_get_boolean (value));
-      break;
-
-    case PROP_EASING_MODE:
-      clutter_table_layout_set_easing_mode (self, g_value_get_ulong (value));
-      break;
-
-    case PROP_EASING_DURATION:
-      clutter_table_layout_set_easing_duration (self, g_value_get_uint (value));
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
       break;
@@ -1563,18 +1564,6 @@ clutter_table_layout_get_property (GObject    *gobject,
       g_value_set_uint (value, priv->col_spacing);
       break;
 
-    case PROP_USE_ANIMATIONS:
-      g_value_set_boolean (value, priv->use_animations);
-      break;
-
-    case PROP_EASING_MODE:
-      g_value_set_ulong (value, priv->easing_mode);
-      break;
-
-    case PROP_EASING_DURATION:
-      g_value_set_uint (value, priv->easing_duration);
-      break;
-
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (gobject, prop_id, pspec);
       break;
@@ -1644,74 +1633,11 @@ clutter_table_layout_class_init (ClutterTableLayoutClass *klass)
                              CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_ROW_SPACING, pspec);
 
-  /**
-   * ClutterTableLayout:use-animations:
-   *
-   * Whether the #ClutterTableLayout should animate changes in the
-   * layout properties.
-   *
-   * By default, #ClutterTableLayout will honour the easing state of
-   * the children when allocating them. Setting this property to
-   * %TRUE will override the easing state with the layout manager's
-   * #ClutterTableLayout:easing-mode and #ClutterTableLayout:easing-duration
-   * properties.
-   *
-   * Since: 1.4
-   *
-   * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
-   *   of the children when allocating them
-   */
-  pspec = g_param_spec_boolean ("use-animations",
-                                P_("Use Animations"),
-                                P_("Whether layout changes should be animated"),
-                                FALSE,
-                                CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_USE_ANIMATIONS, pspec);
-
-  /**
-   * ClutterTableLayout:easing-mode:
-   *
-   * The easing mode for the animations, in case
-   * #ClutterTableLayout:use-animations is set to %TRUE.
-   *
-   * The easing mode has the same semantics of #ClutterAnimation:mode: it can
-   * either be a value from the #ClutterAnimationMode enumeration, like
-   * %CLUTTER_EASE_OUT_CUBIC, or a logical id as returned by
-   * clutter_alpha_register_func().
-   *
-   * The default value is %CLUTTER_EASE_OUT_CUBIC.
-   *
-   * Since: 1.4
-   *
-   * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
-   *   of the children when allocating them
-   */
-  pspec = g_param_spec_ulong ("easing-mode",
-                              P_("Easing Mode"),
-                              P_("The easing mode of the animations"),
-                              0, G_MAXULONG,
-                              CLUTTER_EASE_OUT_CUBIC,
-                              CLUTTER_PARAM_READWRITE);
-  g_object_class_install_property (gobject_class, PROP_EASING_MODE, pspec);
-
-  /**
-   * ClutterTableLayout:easing-duration:
-   *
-   * The duration of the animations, in case #ClutterTableLayout:use-animations
-   * is set to %TRUE.
-   *
-   * The duration is expressed in milliseconds.
-   *
-   * Since: 1.4
-   *
-   * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
-   *   of the children when allocating them
-   */
+  /* a leftover to be compatible to the previous implementation */
   pspec = g_param_spec_uint ("easing-duration",
                              P_("Easing Duration"),
                              P_("The duration of the animations"),
-                             0, G_MAXUINT,
-                             500,
+                             0, G_MAXUINT, 500,
                              CLUTTER_PARAM_READWRITE);
   g_object_class_install_property (gobject_class, PROP_EASING_DURATION, pspec);
 }
@@ -1726,10 +1652,6 @@ clutter_table_layout_init (ClutterTableLayout *layout)
   priv->row_spacing = 0;
   priv->col_spacing = 0;
 
-  priv->use_animations = FALSE;
-  priv->easing_mode = CLUTTER_EASE_OUT_CUBIC;
-  priv->easing_duration = 500;
-
   priv->columns = g_array_new (FALSE, TRUE, sizeof (DimensionData));
   priv->rows = g_array_new (FALSE, TRUE, sizeof (DimensionData));
 }
@@ -2366,26 +2288,17 @@ clutter_table_layout_get_expand (ClutterTableLayout *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them
+ * Deprecated: 1.12: #ClutterTableLayout will honour the
+ *   #ClutterLayoutManager:use-animations property
  */
 void
 clutter_table_layout_set_use_animations (ClutterTableLayout *layout,
                                          gboolean            animate)
 {
-  ClutterTableLayoutPrivate *priv;
-
   g_return_if_fail (CLUTTER_IS_TABLE_LAYOUT (layout));
 
-  priv = layout->priv;
-
-  animate = !!animate;
-  if (priv->use_animations != animate)
-    {
-      priv->use_animations = animate;
-
-      g_object_notify (G_OBJECT (layout), "use-animations");
-    }
+  clutter_layout_manager_set_use_animations (CLUTTER_LAYOUT_MANAGER (layout),
+                                             animate);
 }
 
 /**
@@ -2400,14 +2313,19 @@ clutter_table_layout_set_use_animations (ClutterTableLayout *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.12
+ * Deprecated: 1.12: #ClutterTable will honour the
+ *   #ClutterLayoutManager:use-animations property
  */
 gboolean
 clutter_table_layout_get_use_animations (ClutterTableLayout *layout)
 {
+  ClutterLayoutManager *manager;
+
   g_return_val_if_fail (CLUTTER_IS_TABLE_LAYOUT (layout), FALSE);
 
-  return layout->priv->use_animations;
+  manager = CLUTTER_LAYOUT_MANAGER (layout);
+
+  return clutter_layout_manager_get_use_animations (manager);
 }
 
 /**
@@ -2424,25 +2342,17 @@ clutter_table_layout_get_use_animations (ClutterTableLayout *layout)
  *
  * Since: 1.4
  *
- * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them
+ * Deprecated: 1.12: #ClutterTableLayout will honour the
+ *   #ClutterLayoutManager:easing-mode property
  */
 void
 clutter_table_layout_set_easing_mode (ClutterTableLayout *layout,
                                       gulong              mode)
 {
-  ClutterTableLayoutPrivate *priv;
-
   g_return_if_fail (CLUTTER_IS_TABLE_LAYOUT (layout));
 
-  priv = layout->priv;
-
-  if (priv->easing_mode != mode)
-    {
-      priv->easing_mode = mode;
-
-      g_object_notify (G_OBJECT (layout), "easing-mode");
-    }
+  clutter_layout_manager_set_easing_mode (CLUTTER_LAYOUT_MANAGER (layout),
+                                          mode);
 }
 
 /**
@@ -2455,16 +2365,20 @@ clutter_table_layout_set_easing_mode (ClutterTableLayout *layout,
  *
  * Since: 1.4
  *
- * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them
+ * Deprecated: 1.12: #ClutterTableLayout will honour the
+ *   #ClutterLayoutManager:easing-mode property
  */
 gulong
 clutter_table_layout_get_easing_mode (ClutterTableLayout *layout)
 {
+  ClutterLayoutManager *manager;
+
   g_return_val_if_fail (CLUTTER_IS_TABLE_LAYOUT (layout),
                         CLUTTER_EASE_OUT_CUBIC);
 
-  return layout->priv->easing_mode;
+  manager = CLUTTER_LAYOUT_MANAGER (layout);
+
+  return clutter_layout_manager_get_easing_mode (manager);
 }
 
 /**
@@ -2480,25 +2394,17 @@ clutter_table_layout_get_easing_mode (ClutterTableLayout *layout)
  *
  * Since: 1.4
  *
- * Deprecated: 1.12: #ClutterTableLayout will honour the easing state
- *   of the children when allocating them
+ * Deprecated: 1.12: #ClutterTableLayout will honour the
+ *   #ClutterLayoutManager:easing-duration property
  */
 void
 clutter_table_layout_set_easing_duration (ClutterTableLayout *layout,
                                           guint               msecs)
 {
-  ClutterTableLayoutPrivate *priv;
-
   g_return_if_fail (CLUTTER_IS_TABLE_LAYOUT (layout));
 
-  priv = layout->priv;
-
-  if (priv->easing_duration != msecs)
-    {
-      priv->easing_duration = msecs;
-
-      g_object_notify (G_OBJECT (layout), "easing-duration");
-    }
+  clutter_layout_manager_set_easing_duration (CLUTTER_LAYOUT_MANAGER (layout),
+                                              msecs);
 }
 
 /**
@@ -2516,9 +2422,13 @@ clutter_table_layout_set_easing_duration (ClutterTableLayout *layout,
 guint
 clutter_table_layout_get_easing_duration (ClutterTableLayout *layout)
 {
+  ClutterLayoutManager *manager;
+
   g_return_val_if_fail (CLUTTER_IS_TABLE_LAYOUT (layout), 500);
 
-  return layout->priv->easing_duration;
+  manager = CLUTTER_LAYOUT_MANAGER (layout);
+
+  return clutter_layout_manager_get_easing_duration (manager);
 }
 
 
