@@ -42,7 +42,6 @@
 #include <math.h>
 
 #define CLUTTER_DISABLE_DEPRECATION_WARNINGS
-#include "deprecated/clutter-actor.h"
 
 #include "clutter-alpha.h"
 #include "clutter-behaviour.h"
@@ -51,6 +50,10 @@
 #include "clutter-main.h"
 #include "clutter-private.h"
 
+G_DEFINE_TYPE (ClutterBehaviourScale,
+               clutter_behaviour_scale,
+	       CLUTTER_TYPE_BEHAVIOUR);
+
 struct _ClutterBehaviourScalePrivate
 {
   gdouble x_scale_start;
@@ -60,6 +63,8 @@ struct _ClutterBehaviourScalePrivate
   gdouble y_scale_end;
 };
 
+#define CLUTTER_BEHAVIOUR_SCALE_GET_PRIVATE(obj)        (G_TYPE_INSTANCE_GET_PRIVATE ((obj), CLUTTER_TYPE_BEHAVIOUR_SCALE, ClutterBehaviourScalePrivate))
+
 enum
 {
   PROP_0,
@@ -74,10 +79,6 @@ enum
 
 static GParamSpec *obj_props[PROP_LAST];
 
-G_DEFINE_TYPE_WITH_PRIVATE (ClutterBehaviourScale,
-                            clutter_behaviour_scale,
-                            CLUTTER_TYPE_BEHAVIOUR)
-
 typedef struct {
   gdouble scale_x;
   gdouble scale_y;
@@ -206,6 +207,8 @@ clutter_behaviour_scale_class_init (ClutterBehaviourScaleClass *klass)
   ClutterBehaviourClass *behave_class = CLUTTER_BEHAVIOUR_CLASS (klass);
   GParamSpec *pspec = NULL;
 
+  g_type_class_add_private (klass, sizeof (ClutterBehaviourScalePrivate));
+
   gobject_class->set_property = clutter_behaviour_scale_set_property;
   gobject_class->get_property = clutter_behaviour_scale_get_property;
 
@@ -294,7 +297,7 @@ clutter_behaviour_scale_init (ClutterBehaviourScale *self)
 {
   ClutterBehaviourScalePrivate *priv;
 
-  self->priv = priv = clutter_behaviour_scale_get_instance_private (self);
+  self->priv = priv = CLUTTER_BEHAVIOUR_SCALE_GET_PRIVATE (self);
 
   priv->x_scale_start = priv->x_scale_end = 1.0;
   priv->y_scale_start = priv->y_scale_end = 1.0;
