@@ -1045,7 +1045,7 @@ clutter_device_manager_xi2_translate_event (ClutterEventTranslator *translator,
                                       GINT_TO_POINTER (xev->deviceid));
         clutter_event_set_device (event, device);
 
-        event->touch.axes = translate_axes (event->motion.device,
+        event->touch.axes = translate_axes (event->touch.device,
                                             event->motion.x,
                                             event->motion.y,
                                             stage_x11,
@@ -1098,7 +1098,7 @@ clutter_device_manager_xi2_translate_event (ClutterEventTranslator *translator,
                                       GINT_TO_POINTER (xev->deviceid));
         clutter_event_set_device (event, device);
 
-        event->touch.axes = translate_axes (event->motion.device,
+        event->touch.axes = translate_axes (event->touch.device,
                                             event->motion.x,
                                             event->motion.y,
                                             stage_x11,
