@@ -221,6 +221,7 @@ main (int argc, char **argv)
   TEST_CONFORM_SIMPLE ("/script", animator_properties);
   TEST_CONFORM_SIMPLE ("/script", animator_multi_properties);
   TEST_CONFORM_SIMPLE ("/script", state_base);
+  TEST_CONFORM_SIMPLE ("/script", script_margin);
 
   TEST_CONFORM_SIMPLE ("/timeline", timeline_base);
   TEST_CONFORM_SIMPLE ("/timeline", timeline_markers_from_script);
@@ -231,8 +232,6 @@ main (int argc, char **argv)
 
   TEST_CONFORM_SIMPLE ("/behaviours", behaviours_base);
 
-  TEST_CONFORM_SIMPLE ("/events", events_touch);
-
   /* FIXME - see bug https://bugzilla.gnome.org/show_bug.cgi?id=655588 */
   TEST_CONFORM_TODO ("/cally", cally_text);
 
